# How Politics Matters for EU Funds’ Absorption Problems – A Fuzzy-Set Analysis
# Journal of European Public Policy
# Author: Christian Hagemann, Bavarian School of Public Policy, Technical University Munich
# Contact: christian.hagemann@hfp.tum.de
# September 2017

rm(list=ls())


library(QCA) 
library(QCAGUI)
library(SetMethods)
library(lattice)
library(foreign)
library(devtools)



# Data is already calibrated (conservative strategy, four-value fuzzy-scale)

# Analysis of necessity for the outcome, presence of conditions

QCAfit(dt[, 2:4], dt$outcome, necessity = TRUE, names(dt[, 2:4]))

# Analysis of necessity for the outcome, absence of conditions
QCAfit(1 - dt[, 2:4], dt$outcome, necessity = TRUE, paste("not", names(dt[, 2:4])))

# The same two steps for the absence of the outcome

dt$NegOut <- 1 - dt$outcome

QCAfit(dt[, 2:4], dt$NegOut, necessity = TRUE, names(dt[, 2:4]))

QCAfit(1 - dt[, 2:4], dt$NegOut, necessity = TRUE, paste("not", names(dt[, 2:4])))

# The highest value is found for the presence of LEC for the presence of 
# the outcome. This relationship can be viewed in a plot, to identify the
# extent of contradictions. Jitter added makes it better visible that only four 
# cases are contradictions in degree, but not in kind. There is no case in the 
# crucial first quarter of the plot. 

xy.plot(dt$lec, dt$outcome,
        xlab = "Low Executive Capacities",
        ylab = "Outcome",
        main = "Necessary Conditions",
        labs = rownames(dt),
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)

dt$lecjit <- jitter(dt$lec, factor = 1.5, amount = NULL)

xy.plot(dt$lecjit, dt$outcome,
        xlab = "Low Executive Capacities",
        ylab = "Outcome",
        main = "Necessary Conditions",
        labs = rownames(dt),
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)


# Analysis of sufficiency
# Including three conditions: Low executive capacity, frequent party alternation, 
# and severe crisis.

TT_y <- truthTable(dt, outcome = "outcome",
                   conditions = c("fpa","lec", "sc"),
                   incl.cut1 = 0.75, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y 

# Calculation of complex, intermediate, and parsimonious solution

# All three solutions are the same, as there is only one row not covered
# with empirical cases, and thus no real problem of limited empirical diversity.

sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1)) 

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious

# The same analysis is now conducted for the outcome's complement.

TT_ny <- truthTable(dt, outcome = "outcome", neg.out = TRUE,
                    conditions = c("fpa","lec", "sc"),
                    incl.cut1 = 0.75, 
                    complete = TRUE,
                    show.cases = TRUE,
                    sort.by = c("incl", "n"))

TT_ny

sol_Ncomplex <- eqmcc(TT_ny, details = TRUE, show.cases = TRUE)
sol_Ncomplex


sol_Nintermediate <- eqmcc(TT_ny, details = TRUE, include = "?", 
                           row.dom = TRUE, show.cases = TRUE, 
                           dir.exp = c(0, 0, 0)) 
sol_Nintermediate

sol_Nintermediate$i.sol$C1P1$EC


sol_parsimonious <- eqmcc(TT_ny, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious


# Plots for the Analysis of the Outcome

dt$FPAlec <- pmin(dt$fpa, dt$lec)

dt$FPAlecjit <- jitter(dt$FPAlec, factor = 1, amount = NULL)

dt$LECsc <- pmin(dt$lec, dt$sc)

dt$LECscjit <- jitter(dt$LECsc, factor = 1, amount = NULL)

dt$solution <- pmax(dt$FPAlecjit, dt$LECscjit)

dt$solutionnojit <- pmax(dt$FPAlec, dt$LECsc)


par(mfrow = c(2, 2)) 

xy.plot(dt$FPAlecjit, dt$outcome,
        xlab = "FPA * LEC",
        ylab = "Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)

xy.plot(dt$LECscjit, dt$outcome,
        xlab = "LEC * SC",
        ylab = "Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)


xy.plot(dt$solution, dt$outcome,
        xlab = "Solution Term",
        ylab = "Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)


# Plots for the Absence of the Outcome

dt$nooutcome <- 1 - dt$outcome

dt$nofpa <- 1 - dt$fpa

dt$nosc <- 1 - dt$sc

dt$fpasc <- pmin(dt$nofpa, dt$nosc)

dt$nolec <- 1 - dt$lec

dt$lecSC <- pmin(dt$sc, dt$nolec)

dt$solintermediate <- pmax(dt$nolec, dt$fpasc)

dt$fpascjit <- jitter(dt$fpasc, factor = 1, amount = NULL)

dt$lecSCjit <- jitter(dt$lecSC, factor = 1, amount = NULL)

dt$nolecjit <- jitter(dt$nolec, factor = 1, amount = NULL)


par(mfrow = c(2, 2))

xy.plot(dt$fpascjit, dt$nooutcome,
        xlab = "fpa * sc",
        ylab = "~Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)

xy.plot(dt$lecSCjit, dt$nooutcome,
        xlab = "lec * SC",
        ylab = "~Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)


xy.plot(dt$nolecjit, dt$nooutcome,
        xlab = "lec",
        ylab = "~Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)

xy.plot(dt$solintermediate, dt$nooutcome,
        xlab = "lec + fpa*sc",
        ylab = "~Outcome",
        labs = rownames(dt),
        main = "Sufficient",
        cex.lab = 0.6,
        show.fit = FALSE,
        pos = 2)


### Robustness Checks##########
###############################

# SKT as full member of the Outcome

TT_y <- truthTable(dt, outcome = "outcomeskt",
                   conditions = c("fpa","lec", "sc"),
                   incl.cut1 = 0.75, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y 


sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1)) 

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious


# LVIS as partial member of Party Alternation


TT_y <- truthTable(dt, outcome = "outcome",
                   conditions = c("fpalvis","lec", "sc"),
                   incl.cut1 = 0.75, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y 


sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1))

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious

# Both changes at the same time

TT_y <- truthTable(dt, outcome = "outcomeskt",
                   conditions = c("fpalvis","lec", "sc"),
                   incl.cut1 = 0.75, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y # Truth Table ansehen

sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1)) 

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious


# Further including two versions of policy field: set "Environmental OP", 
# testing two different calibrations. Consistency is lowered here to include
# all members of the outcome into the minimization procedure (like in the original
# analysis).

# Analysis with Environment Condition envop

TT_y <- truthTable(dt, outcome = "outcome",
                   conditions = c("fpa","lec","sc","envop"),
                   incl.cut1 = 0.6, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y 


sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1, 1)) 

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious



# Analysis only with other Environment Condition envop2

TT_y <- truthTable(dt, outcome = "outcome",
                   conditions = c("fpa","lec","sc","envop2"),
                   incl.cut1 = 0.57, 
                   complete = TRUE, 
                   show.cases = TRUE,
                   PRI = TRUE,
                   sort.by = c("incl","n")) 
TT_y 


sol_complex <- eqmcc(TT_y, details = TRUE, show.cases = TRUE)
sol_complex

sol_intermediate <- eqmcc(TT_y, details = TRUE, include = "?", 
                          row.dom = TRUE, show.cases = TRUE, 
                          dir.exp = c(1, 1, 1, 1)) 

sol_intermediate

sol_intermediate$i.sol$C1P1$EC

sol_parsimonious <- eqmcc(TT_y, details = TRUE, include = "?", row.dom = TRUE, show.cases = TRUE)
sol_parsimonious






